/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.isobus.type;

import java.awt.Image;
import java.awt.datatransfer.Transferable;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import javax.swing.Action;
import org.netbeans.api.project.Project;
import org.openide.filesystems.FileObject;
import org.openide.nodes.FilterNode;
import org.openide.nodes.Node;
import org.openide.util.HelpCtx;
import org.openide.util.ImageUtilities;
import org.openide.util.NbBundle;
import org.openide.util.datatransfer.PasteType;
import org.openide.util.lookup.Lookups;
import org.openide.util.lookup.ProxyLookup;

/**
 * <p>Node representing the root folder for imported isobus files</p>
 *
 * @author Gerben Feenstra
 */
@NbBundle.Messages("isobus root folder name=Isobus")
class IsobusRootNode extends FilterNode{             
        
        private static final String ROOTNODE_ICON = "nl/cloudfarming/client/isobus/type/iso.png";
        
        public IsobusRootNode(Project project, Node original) {
            super(original, new TaskfilesNodeChildren(original), new ProxyLookup(Lookups.singleton(project), original.getLookup()));
        }
                
        /**
         * Import isobus action
         *
         * @param context
         * @return
         */
        @Override
        public Action[] getActions(boolean context) {
            return new Action[0];
        }

        @Override
        public Image getIcon(int type) {
            return ImageUtilities.loadImage(ROOTNODE_ICON);
        }

        @Override
        public Image getOpenedIcon(int type) {
            return getIcon(type);
        }

        @Override
        public String getDisplayName() {
            return Bundle.isobus_root_folder_name();
        }

        @Override
        public String getHtmlDisplayName() {
            return getDisplayName();
        }

        // TODO: Fix
        @Override
        public HelpCtx getHelpCtx() {
            return new HelpCtx("nl.cloudfarming.client.isobus.explorer");
        }

        @Override
        public PasteType getDropType(Transferable t, int action, int index) {
            return null;
        }
    
    
    public static class TaskfilesNodeChildren extends FilterNode.Children {

        public TaskfilesNodeChildren(Node node) {
            super(node);
        }

        @Override
        protected Node[] createNodes(Node object) {
            List<Node> result = new ArrayList<>();

            for (Node node : super.createNodes(object)) {
                result.add(new TaskDataFolderNode(node));
            }

            return result.toArray(new Node[0]);
        }
    }
    
    /**
     * Represents the folder where the TASKDATA.XML and optionally GRD00000x.bin and TLG00000x.BIN and TLG00000x.XML are stored    
     * 
     */
    private static class TaskDataFolderNode extends FilterNode {

        private static final String TASKDATA_ICON = "nl/cloudfarming/client/isobus/type/iso.png";
        
        public TaskDataFolderNode(Node original) {
            super(original, new FilterNode.Children(original));
        }

        @Override
        public Action[] getActions(boolean context) {
            return super.getActions(context);
        }

        @Override
        public PasteType getDropType(Transferable t, int action, int index) {
            return null;
        }
        
        @Override
        public Image getOpenedIcon(int type) {
            return getIcon(type);
        }

        // TODO: Fix
        @Override
        public HelpCtx getHelpCtx() {
            return new HelpCtx("nl.cloudfarming.client.isobus.type.explorer");
        }
        
        @Override
        public Image getIcon(int type) {
            return ImageUtilities.loadImage(TASKDATA_ICON);
        }
    }
}
